@@ -72,8 +72,9 @@ function(behavior,phaseX,timeX,v1){
   print(summary(regA))
   yA<-regA$coefficients[1]
   BetaA<-regA$coefficient[2]
-  graphics.off()
   
+  
+  layout(rbind(1,2), heights=c(4,1))
   plot(x1,A,lwd=2,type="p",col="red", xlab="time", ylab="behavior", main=v1 )
   abline(c(yA,BetaA),col='Blue',lty="dashed")
   
